package java.awt;

import java.awt.image.ImageObserver;
import java.text.AttributedCharacterIterator;

public abstract class Graphics
{
    protected Graphics() {
    }
    
    public abstract Graphics create();
    
    public Graphics create(int n, int n2, int n3, int n4) {
        Graphics create = this.create();
        if (create == null) {
            return null;
        }
        create.translate(n, n2);
        create.clipRect(0, 0, n3, n4);
        return create;
    }
    
    public abstract void translate(int p0, int p1);
    
    public abstract Color getColor();
    
    public abstract void setColor(Color p0);
    
    public abstract void setPaintMode();
    
    public abstract void setXORMode(Color p0);
    
    public abstract Font getFont();
    
    public abstract void setFont(Font p0);
    
    public FontMetrics getFontMetrics() {
        return this.getFontMetrics(this.getFont());
    }
    
    public abstract FontMetrics getFontMetrics(Font p0);
    
    public abstract Rectangle getClipBounds();
    
    public abstract void clipRect(int p0, int p1, int p2, int p3);
    
    public abstract void setClip(int p0, int p1, int p2, int p3);
    
    public abstract Shape getClip();
    
    public abstract void setClip(Shape p0);
    
    public abstract void copyArea(int p0, int p1, int p2, int p3, int p4, int p5);
    
    public abstract void drawLine(int p0, int p1, int p2, int p3);
    
    public abstract void fillRect(int p0, int p1, int p2, int p3);
    
    public void drawRect(int n, int n2, int n3, int n4) {
        if (n3 < 0 || n4 < 0) {
            return;
        }
        if (n4 == 0 || n3 == 0) {
            this.drawLine(n, n2, n + n3, n2 + n4);
        }
        else {
            this.drawLine(n, n2, n + n3 - 1, n2);
            this.drawLine(n + n3, n2, n + n3, n2 + n4 - 1);
            this.drawLine(n + n3, n2 + n4, n + 1, n2 + n4);
            this.drawLine(n, n2 + n4, n, n2 + 1);
        }
        return;
    }
    
    public abstract void clearRect(int p0, int p1, int p2, int p3);
    
    public abstract void drawRoundRect(int p0, int p1, int p2, int p3, int p4, int p5);
    
    public abstract void fillRoundRect(int p0, int p1, int p2, int p3, int p4, int p5);
    
    public void draw3DRect(int n, int n2, int n3, int n4, boolean b) {
        Color color = this.getColor();
        Color brighter = color.brighter();
        Color darker = color.darker();
        this.setColor(b ? brighter : darker);
        this.drawLine(n, n2, n, n2 + n4);
        this.drawLine(n + 1, n2, n + n3 - 1, n2);
        this.setColor(b ? darker : brighter);
        this.drawLine(n + 1, n2 + n4, n + n3, n2 + n4);
        this.drawLine(n + n3, n2, n + n3, n2 + n4 - 1);
        this.setColor(color);
    }
    
    public void fill3DRect(int n, int n2, int n3, int n4, boolean b) {
        Color color = this.getColor();
        Color brighter = color.brighter();
        Color darker = color.darker();
        if (!b) {
            this.setColor(darker);
        }
        this.fillRect(n + 1, n2 + 1, n3 - 2, n4 - 2);
        this.setColor(b ? brighter : darker);
        this.drawLine(n, n2, n, n2 + n4 - 1);
        this.drawLine(n + 1, n2, n + n3 - 2, n2);
        this.setColor(b ? darker : brighter);
        this.drawLine(n + 1, n2 + n4 - 1, n + n3 - 1, n2 + n4 - 1);
        this.drawLine(n + n3 - 1, n2, n + n3 - 1, n2 + n4 - 2);
        this.setColor(color);
    }
    
    public abstract void drawOval(int p0, int p1, int p2, int p3);
    
    public abstract void fillOval(int p0, int p1, int p2, int p3);
    
    public abstract void drawArc(int p0, int p1, int p2, int p3, int p4, int p5);
    
    public abstract void fillArc(int p0, int p1, int p2, int p3, int p4, int p5);
    
    public abstract void drawPolyline(int[] p0, int[] p1, int p2);
    
    public abstract void drawPolygon(int[] p0, int[] p1, int p2);
    
    public void drawPolygon(Polygon polygon) {
        this.drawPolygon(polygon.xpoints, polygon.ypoints, polygon.npoints);
    }
    
    public abstract void fillPolygon(int[] p0, int[] p1, int p2);
    
    public void fillPolygon(Polygon polygon) {
        this.fillPolygon(polygon.xpoints, polygon.ypoints, polygon.npoints);
    }
    
    public abstract void drawString(String p0, int p1, int p2);
    
    public abstract void drawString(AttributedCharacterIterator p0, int p1, int p2);
    
    public void drawChars(char[] value, int offset, int count, int n, int n2) {
        this.drawString(new String(value, offset, count), n, n2);
    }
    
    public void drawBytes(byte[] ascii, int offset, int count, int n, int n2) {
        this.drawString(new String(ascii, 0, offset, count), n, n2);
    }
    
    public abstract boolean drawImage(Image p0, int p1, int p2, ImageObserver p3);
    
    public abstract boolean drawImage(Image p0, int p1, int p2, int p3, int p4, ImageObserver p5);
    
    public abstract boolean drawImage(Image p0, int p1, int p2, Color p3, ImageObserver p4);
    
    public abstract boolean drawImage(Image p0, int p1, int p2, int p3, int p4, Color p5, ImageObserver p6);
    
    public abstract boolean drawImage(Image p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, ImageObserver p9);
    
    public abstract boolean drawImage(Image p0, int p1, int p2, int p3, int p4, int p5, int p6, int p7, int p8, Color p9, ImageObserver p10);
    
    public abstract void dispose();
    
    public void finalize() {
        this.dispose();
    }
    
    @Override
    public String toString() {
        return this.getClass().getName() + "[font=" + this.getFont() + ",color=" + this.getColor() + "]";
    }
    
    @Deprecated
    public Rectangle getClipRect() {
        return this.getClipBounds();
    }
    
    public boolean hitClip(int n, int n2, int n3, int n4) {
        Rectangle clipBounds = this.getClipBounds();
        return clipBounds == null || clipBounds.intersects((double)n, (double)n2, (double)n3, (double)n4);
    }
    
    public Rectangle getClipBounds(Rectangle rectangle) {
        Rectangle clipBounds = this.getClipBounds();
        if (clipBounds != null) {
            rectangle.x = clipBounds.x;
            rectangle.y = clipBounds.y;
            rectangle.width = clipBounds.width;
            rectangle.height = clipBounds.height;
        }
        else if (rectangle == null) {
            throw new NullPointerException("null rectangle parameter");
        }
        return rectangle;
    }
}
